==> versioalueet-2024.12.25.tar.gz: versioalueet-2024.12.25/README.md <==
# Versioalueet

Version ranges (Finnish: versioalueet). 

[![License](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/omforme/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/versioalueet/)
[![Downloads](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/versioalueet)
[![Python](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/versioalueete/)
[![Maintenance Status](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/versioalueet/log)

## Documentation

User and developer [documentation of versioalueet](https://codes.dilettant.life/docs/versioalueet).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of versioalueet](https://todo.sr.ht/~sthagen/versioalueet).

## Primary Source repository

The main source of `omforme` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clone of `versioalueet` is:

* [at sourcehut](https://git.sr.ht/~sthagen/versioalueet) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/versioalueet or write plain text email to ~sthagen/versioalueet@lists.sr.ht to submit patches and request support. Thanks.

## Status

Experimental.

**Note**: The default branch is `default`.

==> versioalueet-2025.1.8.tar.gz: versioalueet-2025.1.8/README.md <==
# Versioalueet

Version ranges (Finnish: versioalueet). 

[![License](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/versioalueet/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/versioalueet/)
[![Downloads](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/versioalueet)
[![Python](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/versioalueete/)
[![Maintenance Status](https://git.sr.ht/~sthagen/versioalueet/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/versioalueet/log)

## Documentation

User and developer [documentation of versioalueet](https://codes.dilettant.life/docs/versioalueet).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of versioalueet](https://todo.sr.ht/~sthagen/versioalueet).

## Primary Source repository

The main source of `versioalueet` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clone of `versioalueet` is:

* [at sourcehut](https://git.sr.ht/~sthagen/versioalueet) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/versioalueet or write plain text email to ~sthagen/versioalueet@lists.sr.ht to submit patches and request support. Thanks.

## Status

Experimental.

**Note**: The default branch is `default`.
